from django.core.exceptions import ValidationError

from arkindex.documents.models import Corpus, Entity, EntityType, MetaData, MetaType
from arkindex.process.models import WorkerVersion
from arkindex.project.tests import FixtureTestCase


class TestSaveEntities(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        worker_version = WorkerVersion.objects.first()
        cls.corpus1 = Corpus.objects.create(name="corpus 1")
        cls.corpus2 = Corpus.objects.create(name="corpus 2")
        cls.org_type = EntityType.objects.create(
            name="organization",
            corpus=cls.corpus1
        )
        cls.person_type = EntityType.objects.create(
            name="person",
            corpus=cls.corpus1
        )
        cls.parent = Entity.objects.create(
            name="parent",
            type=cls.org_type,
            corpus=cls.corpus1,
            worker_version=worker_version,
        )
        cls.child = Entity.objects.create(
            type=cls.person_type,
            corpus=cls.corpus1,
            name="child",
            worker_version=worker_version,
        )

    def test_save_entity_in_metadata(self):
        self.parent.corpus = self.corpus2
        element = self.corpus1.elements.create(
            type=self.corpus1.types.create(slug="act"),
            name="element",
        )
        with self.assertRaises(ValidationError):
            MetaData.objects.create(
                name="test 1",
                type=MetaType.Text,
                value="Blah",
                element=element,
                entity=self.parent,
            )
